numina.flow — Blocks for processing — Numina 0.16.dev0 documentation

# `numina.flow` — Blocks for processing

exception `numina.flow.` `FlowError`

  Error base class for flows.

class `numina.flow.` `ParallelFlow`(nodeseq)

  A flow where Nodes are executed in parallel.

class `numina.flow.` `SerialFlow`(nodeseq)

  A flow where Nodes are executed sequentially.

class `numina.flow.node.` `AdaptorNode`(work, ninputs=1, noutputs=1)

  A `Node` that runs a function.

class `numina.flow.node.` `IdNode`

  A Node that returns its inputs.

class `numina.flow.node.` `Node`(ninputs=1, noutputs=1)

  An elemental operation in a Flow.

class `numina.flow.node.` `OutputSelector`(ninputs, indexes)

  A Node that returns part of the results.

class `numina.flow.processing.` `BadPixelCorrector`(badpixelmask, datamodel=None, calibid='calibid-unknown', dtype='float32')

  A Node that corrects a frame from bad pixels.

class `numina.flow.processing.` `BiasCorrector`(biasmap, biasvar=None, datamodel=None, calibid='calibid-unknown', dtype='float32')

  A Node that corrects a frame from bias.

class `numina.flow.processing.` `Corrector`(datamodel=None, calibid='calibid-unknown', dtype='float32')

  A Node that corrects a frame from instrumental signatures.

class `numina.flow.processing.` `DarkCorrector`(darkmap, darkvar=None, datamodel=None, calibid='calibid-unknown', dtype='float32')

  A Node that corrects a frame from dark current.

class `numina.flow.processing.` `DivideByExposure`(datamodel=None, calibid='calibid-unknown', dtype='float32')

  A Node that divides its input by exposure time.

class `numina.flow.processing.` `FlatFieldCorrector`(flatdata, datamodel=None, calibid='calibid-unknown', dtype='float32')

  A Node that corrects a frame from flat-field.

class `numina.flow.processing.` `NonLinearityCorrector`(polynomial, datamodel=None, calibid='calibid-unknown', dtype='float32')

  A Node that corrects a frame from non-linearity.

class `numina.flow.processing.` `SimpleDataModel`(name='UNKNOWN', mappings=None)

  Model of the Data being processed

class `numina.flow.processing.` `SkyCorrector`(skydata, datamodel=None, calibid='calibid-unknown', dtype='float32')

  A Node that corrects a frame from sky.

`numina.flow.processing.` `TagOptionalCorrector`

  alias of `Corrector`